==> algorand_dart-0.0.1-dev.1.tar.gz: lib/src/services/account_service_impl.dart <==
part of 'account_service.dart';

class _AccountService implements AccountService {
  _AccountService(this._dio, {this.baseUrl = null}) {
    ArgumentError.checkNotNull(_dio, '_dio');
  }

  final dio.Dio _dio;

  String? baseUrl;

  @override
  Future<AccountInformation> getAccountByAddress(String address) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$address',
      queryParameters: queryParameters,
      options: dio.RequestOptions(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
        baseUrl: baseUrl,
      ),
      data: _data,
    );
    final value = AccountInformation.fromJson(_result.data);
    return value;
  }

  @override
  Future<SearchAccountsResponse> searchAccounts(
      Map<String, dynamic> queryParameters) async {
    const _extra = <String, dynamic>{};
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts',
      queryParameters: queryParameters,
      options: dio.RequestOptions(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
        baseUrl: baseUrl,
      ),
      data: _data,
    );
    final value = SearchAccountsResponse.fromJson(_result.data);
    return value;
  }

  @override
  Future<AccountResponse> getAccountById(
    String accountId, {
    int? round = null,
  }) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{r'round': round};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$accountId',
      queryParameters: queryParameters,
      options: dio.RequestOptions(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
        baseUrl: baseUrl,
      ),
      data: _data,
    );
    final value = AccountResponse.fromJson(_result.data);
    return value;
  }

  @override
  Future<SearchAccountsResponse> searchAccountsWithBalance(
      int assetId, Map<String, dynamic> queryParameters) async {
    const _extra = <String, dynamic>{};
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/assets/$assetId/balances',
      queryParameters: queryParameters,
      options: dio.RequestOptions(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
        baseUrl: baseUrl,
      ),
      data: _data,
    );
    final value = SearchAccountsResponse.fromJson(_result.data);
    return value;
  }
}

==> algorand_dart-2.0.0-dev.3.tar.gz: lib/src/services/account_service_impl.dart <==
part of 'account_service.dart';

class _AccountService implements AccountService {
  _AccountService(this._dio, {this.baseUrl}) {
    ArgumentError.checkNotNull(_dio, '_dio');
  }

  final dio.Dio _dio;

  String? baseUrl;

  @override
  Future<AccountInformation> getAccountByAddress(String address) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$address',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = AccountInformation.fromJson(_result.data!);
    return value;
  }

  @override
  Future<SearchAccountsResponse> searchAccounts(
      Map<String, dynamic> queryParameters) async {
    const _extra = <String, dynamic>{};
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = SearchAccountsResponse.fromJson(_result.data!);
    return value;
  }

  @override
  Future<AccountResponse> getAccountById(
    String accountId, {
    int? round,
    String? exclude,
  }) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{
      r'round': round,
      r'exclude': exclude,
    };
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$accountId',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = AccountResponse.fromJson(_result.data!);
    return value;
  }

  @override
  Future<SearchAccountsResponse> searchAccountsWithBalance(
      int assetId, Map<String, dynamic> queryParameters) async {
    const _extra = <String, dynamic>{};
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/assets/$assetId/balances',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = SearchAccountsResponse.fromJson(_result.data!);
    return value;
  }

  @override
  Future<AssetsResponse> getAssetsByAccount(String address) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$address/assets',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = AssetsResponse.fromJson(_result.data!);
    return value;
  }

  @override
  Future<CreatedAssetsResponse> getCreatedAssetsByAccount(
    String address,
  ) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$address/created-assets',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = CreatedAssetsResponse.fromJson(_result.data!);
    return value;
  }

  @override
  Future<ApplicationsResponse> getCreatedApplicationsByAccount(
    String address,
  ) async {
    const _extra = <String, dynamic>{};
    final queryParameters = <String, dynamic>{};
    queryParameters.removeWhere((k, v) => v == null);
    final _data = <String, dynamic>{};
    final _result = await _dio.request<Map<String, dynamic>>(
      '/v2/accounts/$address/created-applications',
      queryParameters: queryParameters,
      options: dio.Options(
        method: 'GET',
        headers: <String, dynamic>{},
        extra: _extra,
      ),
      data: _data,
    );
    final value = ApplicationsResponse.fromJson(_result.data!);
    return value;
  }
}
